@@ -4,7 +4,7 @@ import argparse
 
 # Command line arguments
 parser = argparse.ArgumentParser("Mscan", description="Modern network scanner")
-parser.add_argument("--port", default=8000, required=False)
+parser.add_argument("--port", default=8000, required=False, type=int)
 parser.add_argument("--host", default="127.0.0.1", required=False)
 args = parser.parse_args()
 
